docstripy.google
================

docstripy.google.build\_doc
---------------------------

.. automodule:: docstripy.google.build_doc
   :members:
   :undoc-members:
   :show-inheritance:

docstripy.google.parse\_doc
---------------------------

.. automodule:: docstripy.google.parse_doc
   :members:
   :undoc-members:
   :show-inheritance:
